@@ -4,4 +4,4 @@ from dotenv import load_dotenv
 load_dotenv()
 
 api_key = os.getenv("VOCODE_API_KEY")
-BASE_URL = os.getenv("VOCODE_BASE_URL", "api.vocode.dev")
\ No newline at end of file
+base_url = os.getenv("VOCODE_BASE_URL", "api.vocode.dev")
